NICEMAN |---| tools for reproducible neuroimaging
**************************************************

.. toctree::
   :maxdepth: 1

   acknowledgements

Concepts and technologies
=========================

.. toctree::
   :maxdepth: 2

   background
   related
   usecases/index
   glossary
   sandbox/packages

Commands and API
================

.. toctree::
   :maxdepth: 2

   cmdline
   modref

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
